# FedPy

## _Everything Federal Reserve Related_

[![Build Status](https://travis-ci.com/antonio-hickey/FedPy.svg?branch=main)](https://travis-ci.com/antonio-hickey/FedPy)

Open source python package for seamlessly extracting data 
related to Federal Reserve and integrating for your own use.

## Features

- Get current SOMA portfolio value
- Get current SOMA portfolio individual holdings
- Get historic SOMA portfolio value
- Get current TOMO portfolio value

## Installation
Install using pip3:


```sh
pip3 install FedPy
```
